<?php

/*
Plugin Name: WooCommerce Quantum Inline Frame Gateway
Version: 1.0.0
Author: wp@softwarehtec.com
Author Url: www.softwarehtec.com
*/

add_action('plugins_loaded', 'woocommerce_quantuminline_init', 0);

function woocommerce_quantuminline_init() {

    if ( ! class_exists( 'WC_Payment_Gateway' ) ) { return; }

    class WC_Gateway_Quantuminline extends WC_Payment_Gateway {
        var $gwlogin;
        var $restrictkey;
        var $trans_type;
        var $api_uname;
        var $api_key;

        function __construct(){

            global $woocommerce;
            $this->id = 'quantuminline';
            $this->method_title  = __('Quantum Payment Gateway', 'woothemes');
            $this->has_fields 		= true;
            $this->init_form_fields();
            $this->init_settings();
            $this->title  = $this->settings['title'];
            $this->description 	 = $this->settings['description'];
            $this->enabled  = $this->settings['enabled'];

            $this->gwlogin = $this->settings['gwlogin'];
            $this->gwkey = $this->settings['gwkey'];

            $this->restrictkey= $this->settings['restrictkey'];
            $this->trans_type= $this->settings['trans_type'];
            $this->api_uname= $this->settings['api_uname'];
            $this->api_key= $this->settings['api_key'];

            add_action('woocommerce_api_wc_gateway_quantuminline', array($this, 'check_ipn_response')); 

            add_action('woocommerce_receipt_quantuminline', array($this, 'receipt_page'));

            if ( version_compare( WOOCOMMERCE_VERSION, '2.0', '<' ) ) {
                // Pre 2.0
                add_action('woocommerce_update_options_payment_gateways', array($this, 'process_admin_options'));
            } else {
                // 2.0
                add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
            }

            if ( !$this->is_valid_for_use() ) $this->enabled = false;

        }

        function is_valid_for_use() {
            return true;
        }

        function init_form_fields() {

            $this->form_fields = array(
            'title' => array(
            'title' => __( 'Title', 'woothemes' ),
            'type' => 'text', 
            'description' => __( 'The title which the user sees during the checkout.', 'woothemes'), 
            'default' => __( 'Quantum Payment Gateway', 'woothemes' )
            ), 
            'enabled' => array(
            'title' => __( 'Enable/Disable', 'woothemes' ), 
            'label' => __( 'Enable Inatec', 'woothemes' ), 
            'type' => 'select',
            'options'=>array('yes'=>'Yes','no'=>'No'),
            'description' => '', 
            'default' => 'no'
            ), 
            'description' => array(
            'title' => __( 'Description', 'woothemes' ), 
            'type' => 'text', 
            'description' => __( 'The description which the user sees during the checkout.', 'woothemes'), 
            'default' => 'Pay with Quantum Payment Gateway.'
            ),  
            'gwlogin' => array(
            'title' => __( 'Gateway Login', 'woothemes' ), 
            'type' => 'text', 
            'description' => __( 'Gateway Login', 'woothemes'), 
            'default' => ''
            ), 
            'gwkey' => array(
            'title' => __( 'Gateway Key', 'woothemes' ), 
            'type' => 'text', 
            'description' => __( 'Gateway Key', 'woothemes'), 
            'default' => ''
            ),  
            'restrictkey' => array(
            'title' => __( 'Restrict Key', 'woothemes' ), 
            'type' => 'text', 
            'description' => __( 'Restrict Key', 'woothemes'), 
            'default' => ''
            ),  
            'trans_type' => array(
            'title' => __( 'Trans Type', 'woothemes' ), 
            'type' => 'select',
            'options'=>array('AUTH_ONLY'=>'AUTH ONLY','AUTH_CAPTURE'=>'AUTH CAPTURE','SALES'=>'SALES / CREDIT'),
            'description' => __( 'Trans Type', 'woothemes'), 
            'default' => ''
            ),  
            'api_uname' => array(
            'title' => __( 'API UNAME', 'woothemes' ), 
            'type' => 'text', 
            'description' => __( 'API UNAME', 'woothemes'), 
            'default' => ''
            ),  
            'api_key' => array(
            'title' => __( 'API KEY', 'woothemes' ), 
            'type' => 'password', 
            'description' => __( 'API KEY', 'woothemes'), 
            'default' => ''
            )
            );
        }

        function admin_options() {
        ?>
            <h3><?php _e( 'Quantum Payment Gateway', 'woothemes' ); ?></h3>
            <table class="form-table">
            <?php $this->generate_settings_html(); ?>
            </table><!--/.form-table-->
        <?php
        }

        function is_available() {
            if ($this->enabled=="yes") :
                return true;
            endif;	
                return false;
        }


        function payment_fields() {
        ?>
            <?php if ($this->description) : ?><p><?php echo $this->description; ?></p><?php endif; ?>
        <?php
        }

        function process_payment($order_id) {
            global $woocommerce;
            $order = new WC_Order( $order_id );
            return array(
            'result' 	=> 'success',
            'redirect'	=> $order->get_checkout_payment_url( true)
            );
        }


        function generate_quantuminline_form( $order_id ) {
            global $woocommerce;
            $order = new WC_Order( $order_id );
            $customer_id = $order->user_id;

 

            if(!isset($_POST["submit"]))
            {

                if(!empty($customer_id))
                {
                    $last4  = "";
                    $url = "https://secure.quantumgateway.com/cgi/xml_requester.php";
 
                    $xml = "<QGWRequest>\n";
                    $xml .= "<Authentication>\n";
                    $xml .= "<GatewayLogin>".$this->gwlogin."</GatewayLogin>\n";
                    $xml .= "<GatewayKey>".$this->gwkey."</GatewayKey>\n";
                    $xml .= "</Authentication>\n";
                    $xml .= "<Request>\n";
                    $xml .= "<RequestType>ShowVaultDetails</RequestType>\n";
                    $xml .= "<CustomerID>".$customer_id."</CustomerID>\n";
                    $xml .= "</Request>\n";
                    $xml .= "</QGWRequest>\n";
                    $header = "POST $url HTTP/1.1\n";
                    $header.= "Host: ".$_SERVER['SERVER_NAME']."\n";
                    $header.= "Content-Length: ".strlen($xml)."\n";
                    $header.= "Content-type: text/xml; charset=UTF8\n";
                    $header.= "Connection: close; Keep-Alive\n\n";
                    $header.= $xml;
                    $ch = curl_init();
                    curl_setopt($ch, CURLOPT_URL,$url);
                    curl_setopt($ch, CURLOPT_TIMEOUT, 120);
                    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
					curl_setopt($ch, CURLOPT_SSLVERSION, 6);
                    curl_setopt($ch, CURLOPT_CUSTOMREQUEST,$header);
                    $responseXml=curl_exec($ch);
                    curl_close($ch);
 
                    $xml = simplexml_load_string($responseXml);
                    $json = json_encode($xml);
                    $array = json_decode($json,TRUE);

                    if($array["ResponseSummary"]["Status"] == "Success")
                    {
                        $last4 =  $array["Result"]["CreditCardNumber"];
                    }
                }



            ?>
                <form action="" method="post">
                <p>
                <label>Storing Payment Info For Later Use</label><input type="checkbox" name="store" value="1" />
                </p>
                <?php if(!empty($last4)){ ?>
                <p>
                <label>Using Card - <?php echo $last4; ?></label><input type="checkbox" name="oldcard" value="1" />
                </p>
                <?php } ?>
                <p>
                <input type="submit" name="submit" value="Process" />
                </p>
                </form>
            <?php
            }else{

                $amount = number_format($order->get_total(), 2, '.', '');
                $order_id = $order->id;


                if($_POST["oldcard"] == 1)
                {
                    $url = "https://secure.quantumgateway.com/cgi/xml_requester.php";
 
                    $xml = "<QGWRequest>\n";
                    $xml .= "<Authentication>\n";
                    $xml .= "<GatewayLogin>".$this->gwlogin."</GatewayLogin>\n";
                    $xml .= "<GatewayKey>".$this->gwkey."</GatewayKey>\n";
                    $xml .= "</Authentication>\n";
                    $xml .= "<Request>\n";
                    $xml .= "<RequestType>CreateTransaction</RequestType>\n";
                    $xml .= "<TransactionType>CREDIT</TransactionType>\n";
                    $xml .= "<ProcessType>SALES</ProcessType>\n";
                    $xml .= "<Amount>".$amount."</Amount>\n";
                    $xml .= "<CustomerID>".$customer_id."</CustomerID>\n";
                    $xml .= "</Request>\n";
                    $xml .= "</QGWRequest>\n";
                    $header = "POST $url HTTP/1.1\n";
                    $header.= "Host: ".$_SERVER['SERVER_NAME']."\n";
                    $header.= "Content-Length: ".strlen($xml)."\n";
                    $header.= "Content-type: text/xml; charset=UTF8\n";
                    $header.= "Connection: close; Keep-Alive\n\n";
                    $header.= $xml;
                    $ch = curl_init();
                    curl_setopt($ch, CURLOPT_URL,$url);
                    curl_setopt($ch, CURLOPT_TIMEOUT, 120);
                    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                    curl_setopt($ch, CURLOPT_CUSTOMREQUEST,$header);
                    $responseXml=curl_exec($ch);
                    curl_close($ch);
                    $xml = simplexml_load_string($responseXml);
                    $json = json_encode($xml);
                    $array = json_decode($json,TRUE);

                    if($array["ResponseSummary"]["Status"] == "Success")
                    {


                        $data = array();
                        $data["result"]= $array["Result"]["Status"];
                        $data["transID"] = $array["Result"]["TransactionID"];

 
                        $data["authCode"] = $array["Result"]["AuthorizationCode"];
                        $data["Last4CC"] = $array["Result"]["CreditCardNumber"];
                        $data["trans_type"] = "SALES";
                        $data["cardType"] = $array["Result"]["CardType"];
                        $data["CVV2Response"] = serialize($array["Result"]["CVV2ResponseCode"]);
                        $data["AVSResponse"] = serialize($array["Result"]["AVSResponseCode"]);
 
                        $recode_info = "";
                        foreach($data as $key => $v)
                        {
                            $recode_info .= $key.":".$v." | ";
                        }
                        $order->add_order_note( $recode_info );
 
                        update_post_meta( (int) ($order_id), 'quantum_trans_type',  $data["trans_type"]);
                        $order->payment_complete( $data["transID"] );
                        update_post_meta( (int) ($order_id), 'quantum_tid', $data["transID"]);
                        update_post_meta( (int) ($order_id), 'quantum_result', $data["result"]);
                        update_post_meta( (int) ($order_id), 'quantum_last4cc', $data["Last4CC"]);

                        $url =$this->get_return_url( $order );
 
                        wp_redirect($url);
                        die();

                    }
                }




                $fname = $order->billing_first_name;
                $lname = $order->billing_last_name;
                $address = $order->billing_address_1." ".$order->billing_address_2;
                $city = $order->billing_city;
                $state = $order->billing_state;
                $zip = $order->billing_postcode;
                $country = $order->billing_country;
                $phone = $order->billing_phone;
                $email = $order->billing_email;
                $invoice_num =  $order_id;

                $sfname = $order->shipping_first_name;
                $slname = $order->shipping_last_name;

                $saddress = $order->shipping_address_1." ".$order->shipping_address_2;
                $scity = $order->shipping_city;
                $sstate = $order->shipping_state;
                $szip = $order->shipping_postcode;
                $scountry = $order->shipping_country;

                $trans_type = $this->trans_type;
                $method="0";
                if($_POST["store"] == 1)      {	$addtoVault="Y"; } else { $addtoVault="N"; }
                $skipshipping="Y";
                $width="800";
                $height="800";

                $approved_url = WC()->api_request_url( 'WC_Gateway_Quantuminline' );
                #$declined_url =  esc_url( $order->get_cancel_order_url() );
				$declined_url = $approved_url."&quantum=cancel&oid=".$order_id;
 
                    $quantum = quantumilf_getCode($this->api_uname,$this->api_key, $width, $height ,$amount, $order_id, $customer_id, $method, $addtoVault, $skipshipping, $fname, $lname, $address, $city, $state, $zip, $country, $phone, $email, $invoice_num, $sfname, $slname, $saddress, $scity, $sstate, $szip, $scountry, $trans_type, $approved_url , $declined_url, "WooCommerce :  Quantum Payment Gateway");


                echo $quantum['script'];

                echo $quantum['iframe'];

            }
        }

        function receipt_page( $order ) {

            echo $this->generate_quantuminline_form( $order );

        }

        function check_ipn_response() {


            if(isset($_GET["quantum"]))
            {
                $oid = intval($_GET["oid"]);
                $post_type = get_post_type($oid) ;

                if($post_type == "shop_order")
                {
                    $order = new WC_Order($oid );
 
                    if($_GET["quantum"] == "return")
                    {
                         $Last4CC = get_post_meta( (int)$oid, 'quantum_last4cc', true);
                         $amount = number_format($order->get_total(), 2, '.', '');
                         $tid = get_post_meta( (int)$oid, 'quantum_tid', true);


                         $url = "https://secure.quantumgateway.com/cgi/xml_requester.php";
                         $xml = "<QGWRequest>\n";
                         $xml .= "<Authentication>\n";
                         $xml .= "<GatewayLogin>".$this->gwlogin."</GatewayLogin>\n";
                         $xml .= "<GatewayKey>".$this->restrictkey."</GatewayKey>\n";
                         $xml .= "</Authentication>\n";
                         $xml .= "<Request>\n";
                         $xml .= "<RequestType>ProcessSingleTransaction</RequestType>\n";
                         $xml .= "<TransactionType>CREDIT</TransactionType>\n";
                         $xml .= "<ProcessType>RETURN</ProcessType>\n";
                         $xml .= "<PaymentType>CC</PaymentType>\n";
                         $xml .= "<Amount>".$amount."</Amount>\n";
                         $xml .= "<CreditCardNumber>".$Last4CC."</CreditCardNumber>\n";
                         $xml .= "<TransactionID>".$tid."</TransactionID>\n";
                         $xml .= "</Request>\n";
                         $xml .= "</QGWRequest>\n";
                         $header = "POST $url HTTP/1.1\n";
                         $header.= "Host: ".$_SERVER['SERVER_NAME']."\n";
                         $header.= "Content-Length: ".strlen($xml)."\n";
                         $header.= "Content-type: text/xml; charset=UTF8\n";
                         $header.= "Connection: close; Keep-Alive\n\n";
                         $header.= $xml;
                         $ch = curl_init();
                         curl_setopt($ch, CURLOPT_URL,$url);
                         curl_setopt($ch, CURLOPT_TIMEOUT, 120);
                         curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                         curl_setopt($ch, CURLOPT_CUSTOMREQUEST,$header);
                         $responseXml=curl_exec($ch);
 
                         curl_close($ch);

                         $xml = simplexml_load_string($responseXml);
                         $json = json_encode($xml);
                         $array = json_decode($json,TRUE);

 
                         $statusdesc= $array["ResponseSummary"]["StatusDescription"];



                         if($array["ResponseSummary"]["Status"] == "Success") {

                             update_post_meta( (int) $oid, 'quantum_trans_type', "RETURN");
 
                             $order->update_status( 'refunded',$array["ResponseSummary"]["StatusDescription"]);
                         }
                    }

                    if($_GET["quantum"] == "force")
                    {


                        $amount = number_format($order->get_total(), 2, '.', '');
                        $tid = get_post_meta( (int)$oid, 'quantum_tid', true);

                        $url = "https://secure.quantumgateway.com/cgi/xml_requester.php";
                        $xml = "<QGWRequest>\n";
                        $xml .= "<Authentication>\n";
                        $xml .= "<GatewayLogin>".$this->gwlogin."</GatewayLogin>\n";
                        $xml .= "<GatewayKey>".$this->restrictkey."</GatewayKey>\n";
                        $xml .= "</Authentication>\n";
                        $xml .= "<Request>\n";
                        $xml .= "<RequestType>ProcessSingleTransaction</RequestType>\n";
                        $xml .= "<TransactionType>CREDIT</TransactionType>\n";
                        $xml .= "<ProcessType>PREVIOUS_SALE</ProcessType>\n";
                        $xml .= "<TransactionID>".$tid ."</TransactionID>\n";
                        $xml .= "</Request>\n";
                        $xml .= "</QGWRequest>\n";
                        $header = "POST $url HTTP/1.1\n";
                        $header.= "Host: ".$_SERVER['SERVER_NAME']."\n";
                        $header.= "Content-Length: ".strlen($xml)."\n";
                        $header.= "Content-type: text/xml; charset=UTF8\n";
                        $header.= "Connection: close; Keep-Alive\n\n";
                        $header.= $xml;
                        $ch = curl_init();
                        curl_setopt($ch, CURLOPT_URL,$url);
                        curl_setopt($ch, CURLOPT_TIMEOUT, 120);
                        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                        curl_setopt($ch, CURLOPT_CUSTOMREQUEST,$header);
                        $responseXml=curl_exec($ch);
                        curl_close($ch);
 
                        $xml = simplexml_load_string($responseXml);
                        $json = json_encode($xml);
                        $array = json_decode($json,TRUE);

                        $statusdesc= $array["ResponseSummary"]["StatusDescription"];



                        if($array["ResponseSummary"]["Status"] == "Success") {

                            update_post_meta( (int) $oid, 'quantum_trans_type', "PREVIOUS_SALE");
 
                            $order->update_status( 'quantum-force',$array["ResponseSummary"]["StatusDescription"]);
                        }

                    }

                    if($_GET["quantum"] == "void")
                    {

                        $amount = number_format($order->get_total(), 2, '.', '');
                        $tid = get_post_meta( (int)$oid, 'quantum_tid', true);


                        $url = "https://secure.quantumgateway.com/cgi/xml_requester.php";
                        $xml = "<QGWRequest>\n";
                        $xml .= "<Authentication>\n";
                        $xml .= "<GatewayLogin>".$this->gwlogin."</GatewayLogin>\n";
                        $xml .= "<GatewayKey>".$this->restrictkey."</GatewayKey>\n";
                        $xml .= "</Authentication>\n";
                        $xml .= "<Request>\n";
                        $xml .= "<RequestType>ProcessSingleTransaction</RequestType>\n";
                        $xml .= "<TransactionType>CREDIT</TransactionType>\n";
                        $xml .= "<ProcessType>VOID</ProcessType>\n";
                        $xml .= "<TransactionID>".$tid ."</TransactionID>\n";
                        $xml .= "</Request>\n";
                        $xml .= "</QGWRequest>\n";
                        $header = "POST $url HTTP/1.1\n";
                        $header.= "Host: ".$_SERVER['SERVER_NAME']."\n";
                        $header.= "Content-Length: ".strlen($xml)."\n";
                        $header.= "Content-type: text/xml; charset=UTF8\n";
                        $header.= "Connection: close; Keep-Alive\n\n";
                        $header.= $xml;
                        $ch = curl_init();
                        curl_setopt($ch, CURLOPT_URL,$url);
                        curl_setopt($ch, CURLOPT_TIMEOUT, 120);
                        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                        curl_setopt($ch, CURLOPT_CUSTOMREQUEST,$header);
                        $responseXml=curl_exec($ch);
                        curl_close($ch);
 
 
                        $xml = simplexml_load_string($responseXml);
                        $json = json_encode($xml);
                        $array = json_decode($json,TRUE);



                        $statusdesc= $array["ResponseSummary"]["StatusDescription"];



                        if($array["ResponseSummary"]["Status"] == "Success") {

                            update_post_meta( (int) $oid, 'quantum_trans_type', "VOID");
 
                            $order->update_status( 'cancelled',$array["ResponseSummary"]["StatusDescription"]);
                        }

                    }

                }


                $url = admin_url('post.php?post='.$oid.'&action=edit');
                wp_redirect($url);
                die();
            }


            $data = array();
            $data["result"]= $_GET["trans_result"];
            $data["transID"] = $_GET["transID"];
            $ID = $_GET["ID"];
            $data["decline_reason"] = $_GET["decline_reason"];
            $data["errorcode"] = $_GET["errorcode"];
            $data["authCode"] = $_GET["authCode"];
            $data["Last4CC"] = $_GET["Last4CC"];
            $data["trans_type"] = $_GET["trans_type"];
            $data["cardType"] = $_GET["cardType"];
            $data["CVV2Response"] = $_GET["CVV2Response"];
            $data["AVSResponse"] = $_GET["AVSResponse"];


            $order = new WC_Order( $ID );

            if( $order->id != $ID || empty($ID ))
            {
                $url = "/";
            ?>
                <script type="text/javascript">
                window.top.location.href = "<?php echo $url  ?>";
                </script>

            <?php

                die();

            }
##APPROVED
            if($data["result"] == "APPROVED")
            {
                $recode_info = "";
                foreach($data as $key => $v)
                {
                    $recode_info .= $key.":".$v." | ";
                }
                $order->add_order_note( $recode_info );

                update_post_meta( (int) ($ID), 'quantum_trans_type', $this->trans_type);
                $order->payment_complete( $data["transID"] );
                update_post_meta( (int) ($ID), 'quantum_tid', $data["transID"]);
                update_post_meta( (int) ($ID), 'quantum_result', $data["result"]);
                update_post_meta( (int) ($ID), 'quantum_last4cc', $data["Last4CC"]);

                $url =$this->get_return_url( $order );
            ?>
                <script type="text/javascript">
                window.top.location.href = "<?php echo $url  ?>";
                </script>
            <?php
            die();
            }
##DECLINED
            if($data["result"] == "DECLINED")
            {
$order->update_status( 'failed', __( 'Payment was declined by Credit Card Issuer.', 'woocommerce' ) );

                $url =$this->get_return_url( $order );
            ?>
                <script type="text/javascript">
                window.top.location.href = "<?php echo $url  ?>";
                </script>
            <?php
            die();
            }

#anything other than APPROVED or DECLINED
            update_post_meta( (int) ($ID), 'quantum_result', $data["result"]);

            $url = esc_url( $order->get_cancel_order_url() );
            ?>
                <script type="text/javascript">
                window.top.location.href = "<?php echo $url  ?>";
                </script>

            <?php

            die();
        }

    }

    function add_quantuminline_gateway($methods) {
        $methods[] = 'WC_Gateway_Quantuminline';
        return $methods;
    }

    add_filter('woocommerce_payment_gateways', 'add_quantuminline_gateway' );
}


function quantuminline_profile_function() {

    $cid = get_current_user_id();

    $quantuminline_settings = (get_option( 'woocommerce_quantuminline_settings' ));

 

    if($cid != 0)
    {
        $quantum = quantumilf_getCode( $quantuminline_settings["api_uname"], $quantuminline_settings["api_key"], '800', '800', '0', '0', $cid, 'CustomerEdit');

        echo $quantum['script'];
        echo $quantum['iframe'];
    }
}

function quantuminline_shortcodes(){
   add_shortcode('quantuminline-profile', 'quantuminline_profile_function');
}

 

add_action( 'init', 'quantuminline_shortcodes');
 


if(isset($_GET["post"]))
{
    $post_type = get_post_type( $_GET["post"] ) ;
    if($post_type == "shop_order")
    {
        $quantum_trans_type = get_post_meta( (int) $_GET["post"], 'quantum_trans_type', true);

        if(!empty($quantum_trans_type))
        {
            add_action( 'load-post.php', 'quantuminline_post_meta_boxes_setup' );
            add_action( 'load-post-new.php', 'quantuminline_post_meta_boxes_setup' );
        }
    }
}

function quantuminline_post_meta_boxes_setup() {
    /* Add meta boxes on the 'add_meta_boxes' hook. */
    add_action( 'add_meta_boxes', 'quantuminline_add_post_meta_boxes' );
}

function quantuminline_add_post_meta_boxes() {
    add_meta_box('quantuminline_section',__('Quantuminline Section', 'quantuminline_metabox' ),'quantuminline_class_meta_box','shop_order','advanced','high');
}


function quantuminline_class_meta_box( $post ) {

    $quantum_trans_type = get_post_meta( (int) $post->ID, 'quantum_trans_type', true);
    $quantum_tid = get_post_meta( (int) $post->ID, 'quantum_tid', true);
    $quantum_result = get_post_meta( (int) $post->ID, 'quantum_result', true);


 
?>
<style>
.refund-items{display:none !important;}
</style>

<p>
<?php

$admin_path = WC()->api_request_url( 'WC_Gateway_Quantuminline' );
 
if($quantum_result == "APPROVED" && $quantum_trans_type != "RETURN" && $quantum_trans_type != "VOID" )
{
    if ( !get_option('permalink_structure') ) 
    echo " <a href='".$admin_path."&quantum=return&oid=".$post->ID."'>Refund</a> ";
    else
    echo " <a href='".$admin_path."?quantum=return&oid=".$post->ID."'>Refund</a> ";

    if ( !get_option('permalink_structure') ) 
    echo " <a href='".$admin_path."&quantum=void&oid=".$post->ID."'>Void</a> ";
    else
    echo " <a href='".$admin_path."?quantum=void&oid=".$post->ID."'>Void</a> ";
}

if($quantum_result == "APPROVED" && $quantum_trans_type == "AUTH_ONLY" )
{
    if ( !get_option('permalink_structure') ) 
    echo " <a href='".$admin_path."&quantum=force&oid=".$post->ID."'>Force</a> ";
    else
    echo " <a href='".$admin_path."?quantum=force&oid=".$post->ID."'>Force</a> ";
}
?>
</p>
<?php
}






function register_quantum_order_status() {
    register_post_status( 'wc-quantum-force', array(
    'label' => 'Auth Forced',
    'public' => true,
    'exclude_from_search' => false,
    'show_in_admin_all_list' => true,
    'show_in_admin_status_list' => true,
    'label_count' => _n_noop( 'Auth Forced <span class="count">(%s)</span>', 'Auth Forced <span class="count">(%s)</span>' )
    ) );
}

add_action( 'init', 'register_quantum_order_status' );
 
function add_quantum_to_order_statuses( $order_statuses ) {
    $new_order_statuses = array();

    foreach ( $order_statuses as $key => $status ) {
        $new_order_statuses[ $key ] = $status;
        if ( 'wc-processing' === $key ) {
            $new_order_statuses['wc-quantum-force'] = 'Auth Forced';
        }
    }

    return $new_order_statuses;
}

add_filter( 'wc_order_statuses', 'add_quantum_to_order_statuses' ); 



if(!function_exists('_quantumilf_http_post'))
{
function _quantumilf_http_post($host, $path, $data, $port = 80) {

        $req = _quantumilf_qsencode ($data);
		$response = '';
		if ( (PHP_VERSION >= 4.3) && ($fs = @fsockopen('ssl://secure.quantumgateway.com', 443, $errno, $errstr, 30)) ) {
		
			$http_request  = "POST $path HTTP/1.0\r\n";
			$http_request .= "Host: $host\r\n";
			$http_request .= "Content-Type: application/x-www-form-urlencoded;\r\n";
			$http_request .= "Content-Length: " . strlen($req) . "\r\n";
			$agent = "Mozilla/5.0 (Windows; U; Windows NT 5.0; en-US; rv:1.4) Gecko/20030624 Netscape/7.1 (affgrabber)";
			$http_request .= "User-Agent: $agent\r\n";
			$http_request .= "\r\n";
			$http_request .= $req;
 
		    fwrite($fs, $http_request);
			while (!feof($fs)) {
				$response .= fgets($fs, 1160); // One TCP-IP packet
			}
			
    		fclose($fs);
			$response = explode("\r\n\r\n", $response, 2);
		} elseif (function_exists('curl_exec')) {
		
			 $ch = curl_init();
			$curl_url = 'https://secure.quantumgateway.com' . $path;
			curl_setopt($ch, CURLOPT_URL, $curl_url);
			curl_setopt($ch, CURLOPT_POST, true);
			curl_setopt($ch, CURLOPT_POSTFIELDS, $req);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($ch, CURLOPT_HEADER, false);
			curl_setopt($ch, CURLOPT_TIMEOUT, 30);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		
			$result = curl_exec($ch);
			$response = explode("\r\n\r\n", $result, 2);
			$response[1] = $response[0];
			curl_close($ch);
			
			
		} 
        return $response;
}
}

if(!function_exists('_quantumilf_qsencode'))
{
function _quantumilf_qsencode ($data) {
        $req = "";
        foreach ( $data as $key => $value )
                $req .= $key . '=' . urlencode( stripslashes($value) ) . '&';

        // Cut the last '&'
        $req=substr($req,0,strlen($req)-1);
        return $req;
}
}

if(!function_exists('quantumilf_getCode'))
{


function quantumilf_getCode($API_Username, $API_Key, $width, $height, $amount='0', $id='0', $custid='0', $method='0', $addtoVault='N', $skipshipping='N', $fname=false, $lname=false, $address=false, $city=false, $state=false, $zip=false, $country=false, $phone=false, $email=false, $invoice_num=false, $sfname=false, $slname=false, $saddress=false, $scity=false, $sstate=false, $szip=false, $scountry=false, $trans_type=false, $post_return_url_approved=false, $post_return_url_declined=false, $Vendor=false) {
	$thereturn = array();
	$random = rand(1111111111, 9999999999);
	$random = (int)$random;
	$response = _quantumilf_http_post("secure.quantumgateway.com", "/cgi/ilf_authenticate.php",
                                          array (
                                                 'API_Username' => $API_Username,
                                                 'API_Key' => $API_Key,
                                                 'randval' => $random,
												 'lastip' => $_SERVER['REMOTE_ADDR']
                                                 ), 443
                                          );
										  
					print_r($response, 1);					  
										  
								  
	if (is_array($response)) {
		if ($response[1] != 'error') {
			$extrapars = '';
			if ($method != '0') {
				$extrapars .= "&METHOD=$method";	
			}
			if ($addtoVault != 'N') {
				$extrapars .= "&AddToVault=$addtoVault";				
			}
			if ($skipshipping != 'N') {
				$extrapars .= "&skip_shipping_info=$skipshipping";				
			}
			if ($custid != '0') {
				$extrapars .= "&CustomerID=" . urlencode($custid);				
			}
			if ($amount != '0')	{
				$extrapars .= "&Amount=$amount";
			}
			if ($id > '0')	{
				$extrapars .= "&ID=" .$id;
			}
			#$extrapars .= "&skip_shipping_info=Y&ilf_API_Style=2"; 
			#custom/advanced
			if(!$fname) {} else {
			$extrapars .= "&FNAME=$fname";	
			}
			if(!$lname) {} else {
			$extrapars .= "&LNAME=$lname";	
			}
			if(!$address) {} else {
			$extrapars .= "&BADDR1=$address";	
			}
			if(!$city) {} else {
			$extrapars .= "&BCITY=$city";	
			}
			if(!$state) {} else {
			$extrapars .= "&BSTATE=$state";	
			}
			if(!$zip) {} else {
			$extrapars .= "&BZIP1=$zip";	
			}
			if(!$country) {} else {
			$extrapars .= "&BCOUNTRY=$country";	
			}
			if(!$phone) {} else {
			$extrapars .= "&phone=$phone";	
			}
			if(!$email) {} else {
			$extrapars .= "&BCUST_EMAIL=$email";	
			}
			if(!$invoice_num) {} else {
			$extrapars .= "&invoice_num=$invoice_num";	
			}
			
			if(!$sfname) {} else {
			$extrapars .= "&SFNAME=$sfname";	
			}
			if(!$slname) {} else {
			$extrapars .= "&SLNAME=$slname";	
			}
			if(!$saddress) {} else {
			$extrapars .= "&SADDR1=$saddress";	
			}
			if(!$scity) {} else {
			$extrapars .= "&SCITY=$scity";	
			}
			if(!$sstate) {} else {
			$extrapars .= "&SSTATE=$sstate";	
			}
			if(!$szip) {} else {
			$extrapars .= "&SZIP1=$szip";	
			}
			if(!$scountry) {} else {
			$extrapars .= "&SCOUNTRY=$scountry";	
			}
			if(!$trans_type) {} else {
			$extrapars .= "&trans_type=$trans_type";	
			}
			if(!$post_return_url_approved) {} else {
			$extrapars .= "&post_return_url_approved=$post_return_url_approved";	
			}
			if(!$post_return_url_declined) {} else {
			$extrapars .= "&post_return_url_declined=$post_return_url_declined";	
			}
			if(!$Vendor) {} else {
			$extrapars .= "&Vendor=$Vendor";	
			}
			if($method  == 0){
			#$extrapars .= "&override_trans_email=Y";	#Leave the default settings of gateway
			$extrapars .= "&override_email_customer=N";	#never send as the shopping cart sends an email
                        }

			$thereturn['iframe'] = '<iframe src="https://secure.quantumgateway.com/cgi/ilf.php?k=' . $response[1] . '&ip=' . $_SERVER['REMOTE_ADDR'] . $extrapars . '" height="' . $height . '" width="' . $width . '" frameborder="0"></iframe><br/>';	
			$thereturn['script']  = '<script src="https://secure.quantumgateway.com/javascript/prototype.js" type="text/javascript"></script>
<script type="text/javascript">
function refreshSession(thek, theip) {
	var randomnumber=Math.random();
	var tposturl = "quantum_iframe.php?cachebuster=" + randomnumber;
	var thequerystring = "ajax=true&ip=" + theip + "&k=" + thek;
	var thecheck = new Ajax.Request(tposturl, {	method: "post", parameters: thequerystring });
	
}
setInterval("refreshSession(\'' . $response[1] . '\',\'' . $_SERVER['REMOTE_ADDR'] . '\')",20000);
</script>
';
		}
	}
	return $thereturn;
}

 
}